//---------------------------------------------------------------------------------------
//  FILE:   XComDownloadableContentInfo_QuickStart.uc                                    
//           
//	Use the X2DownloadableContentInfo class to specify unique mod behavior when the 
//  player creates a new campaign or loads a saved game.
//  
//---------------------------------------------------------------------------------------
//  Copyright (c) 2016 Firaxis Games, Inc. All rights reserved.
//---------------------------------------------------------------------------------------

class X2DownloadableContentInfo_QuickStart extends X2DownloadableContentInfo config(QuickStart);

/// <summary>
/// This method is run if the player loads a saved game that was created prior to this DLC / Mod being installed, and allows the 
/// DLC / Mod to perform custom processing in response. This will only be called once the first time a player loads a save that was
/// create without the content installed. Subsequent saves will record that the content was installed.
/// </summary>
static event OnLoadedSavedGame()
{ }

/// <summary>
/// Called when the player starts a new campaign while this DLC / Mod is installed
/// </summary>
static event InstallNewCampaign(XComGameState StartState)
{
	local XComGameStateHistory History;
	local XComGameState_HeadquartersXCom XComHQ;
	local XComGameState_BattleData BattleData;
	local UIScreen Screen;
	local XComGameState_Unit Unit;
	local XComGameState_Item Item;
	local X2ItemTemplateManager ItemTemplateManager;
	local X2ItemTemplate ItemTemplate;

	local int i;
	local StateObjectReference EnemyRef;
	local bool GaveLoot;

	`log("QuickStart: InstallNewCampaign");

	History = `XCOMHISTORY;
	XComHQ = XComGameState_HeadquartersXCom(History.GetSingleGameStateObjectForClass(class'XComGameState_HeadquartersXCom'));
	XComHQ = XComGameState_HeadquartersXCom(StartState.CreateStateObject(class'XComGameState_HeadquartersXCom', XComHQ.ObjectID));
	StartState.AddStateObject(XComHQ);

	`log("QuickStart: Setting HQ Values");
	// Set some values for the HQ
	XComHQ.bDontShowSetupMovies = true;
	XComHQ.bHasVisitedEngineering = true;
	XComHQ.bHasVisitedLabs = true;
	XComHQ.bJustWentOnFirstMission = true;
	XComHQ.bHasSeenFirstGrenadier = true;
	XComHQ.bHasSeenFirstRanger = true;
	XComHQ.bHasSeenFirstSharpshooter = true;
	XComHQ.bHasSeenFirstSpecialist = true;
	XComHQ.bReturningFromMission = true;
	XComHQ.bSimCombatVictory = true;

	// level up the soldiers
	GaveLoot = false;
	for (i = 0; i < XComHQ.Squad.Length; i++)
	{
		if (XComHQ.Squad[i].ObjectID > 0)
		{
			Unit = XComGameState_Unit(History.GetGameStateForObjectID(XComHQ.Squad[i].ObjectID));
			Unit = XComGameState_Unit(StartState.CreateStateObject(class'XComGameState_Unit', Unit.ObjectID));
			//Unit.iNumMissions = 1; // not needed
			Unit.SimGetKill(EnemyRef);
			Unit.SimGetKill(EnemyRef);
			Unit.SetXPForRank(1);
			if(!GaveLoot)
			{
				ItemTemplateManager = class'X2ItemTemplateManager'.static.GetItemTemplateManager();
				// CorpseAdventTrooper
				// CorpseAdventOfficer
				// CorpseSectoid
				// function bool AddItemToInventory(XComGameState_Item Item, EInventorySlot Slot, XComGameState NewGameState, optional bool bAddToFront)
				// eInvSlot_Backpack
				ItemTemplate = ItemTemplateManager.FindItemTemplate('CorpseAdventTrooper');
				Item = ItemTemplate.CreateInstanceFromTemplate(StartState);
				Item.Quantity = 6;
				StartState.AddStateObject(Item);
				Unit.AddItemToInventory(Item, eInvSlot_Backpack, StartState);

				ItemTemplate = ItemTemplateManager.FindItemTemplate('CorpseAdventOfficer');
				Item = ItemTemplate.CreateInstanceFromTemplate(StartState);
				Item.Quantity = 1;
				StartState.AddStateObject(Item);
				Unit.AddItemToInventory(Item, eInvSlot_Backpack, StartState);

				ItemTemplate = ItemTemplateManager.FindItemTemplate('CorpseSectoid');
				Item = ItemTemplate.CreateInstanceFromTemplate(StartState);
				Item.Quantity = 1;
				StartState.AddStateObject(Item);
				Unit.AddItemToInventory(Item, eInvSlot_Backpack, StartState);

				GaveLoot = true;
			}
			StartState.AddStateObject(Unit);
		}
	}


	// give first mission loot


	// manually create some BattleData
	BattleData = XComGameState_BattleData(StartState.CreateStateObject(class'XComGameState_BattleData'));
	BattleData.m_strOpName = "Operation Quick Start";
	BattleData.m_iMissionID = -1;
	BattleData.m_bIsFirstMission = true;
	BattleData.bLocalPlayerWon = true;
	BattleData.bMissionAborted = false;
	StartState.AddStateObject(BattleData);
	
	// complete the objective for having completed the first mission
	// Bypass the initial mission
	// just removing it/marking it completed causes the game to crash?
	`log("QuickStart: Removing starting mission");
	RemoveStartingMission(StartState, History);
	//`XEVENTMGR.TriggerEvent('PreMissionDone', , , StartState);
	`HQPRES.m_bExitFromSimCombat = true;

	class'XComGameStateContext_StrategyGameRule'.static.CreateStrategyGameStartFromTactical();


	Screen = `SCREENSTACK.GetCurrentScreen();
	Screen.ConsoleCommand("open Avenger_Root?game=XComGame.XComHeadQuartersGame");

	`HQPC.GotoState( 'Headquarters' );
}

static function RemoveStartingMission(XComGameState StartState, XComGameStateHistory History)
{
	local XComGameState_MissionSite MissionState;
	`log("In RemoveStartingMission");

	//foreach History.IterateByClassType(class'XComGameState_MissionSite', MissionState)
	foreach StartState.IterateByClassType(class'XComGameState_MissionSite', MissionState)
	{
		if(MissionState.GetMissionSource().bStart)
		{
		`log("Removing mission");
		`log(MissionState.ObjectID);
			StartState.RemoveStateObject(MissionState.ObjectID);
		}
	}

	// when removing the first mission, we still have to complete the objective for having completed the first mission
	`XEVENTMGR.TriggerEvent('PreMissionDone', , , StartState);

	//`XCOMGAME.GameRuleset.SubmitGameState(StartState);
}


/**
	local XComGameStateHistory History;
	local XComGameState_HeadquartersXCom XComHQ;
	local XComGameState_CampaignSettings CampaignSettingsStateObject;
	local int SelectedDifficulty;
	local bool IronmanFromShell;
	local UIShellDifficulty Shell;

	`log("QuickStart InstallNewCampaign");
	History = `XCOMHISTORY;
	
	//XComHQ = XComGameState_HeadquartersXCom(History.GetSingleGameStateObjectForClass(class'XComGameState_HeadquartersXCom'));
	//XComHQ = XComGameState_HeadquartersXCom(StartState.CreateStateObject(class'XComGameState_HeadquartersXCom', XComHQ.ObjectID));

	// Set some values for the HQ
	//XComHQ.bDontShowSetupMovies = true;
	//XComHQ.bHasVisitedEngineering = true;
	//XComHQ.bHasVisitedLabs = true;
	//XComHQ.bJustWentOnFirstMission = true;
	//XComHQ.bHasSeenFirstGrenadier = true;
	//XComHQ.bHasSeenFirstRanger = true;
	//XComHQ.bHasSeenFirstSharpshooter = true;
	//XComHQ.bHasSeenFirstSpecialist = true;
	//XComHQ.bReturningFromMission = true;
	//XComHQ.bSimCombatVictory = true;
	//StartState.AddStateObject(XComHQ);
	
	CampaignSettingsStateObject = XComGameState_CampaignSettings(History.GetSingleGameStateObjectForClass(class'XComGameState_CampaignSettings', true));
	CampaignSettingsStateObject = XComGameState_CampaignSettings(StartState.CreateStateObject(class'XComGameState_CampaignSettings', CampaignSettingsStateObject.ObjectID));

	CampaignSettingsStateObject.bSkipFirstTactical = true;
	CampaignSettingsStateObject.bCheatStart = false;
	CampaignSettingsStateObject.SetStartTime(StartState.TimeStamp);
	// grab the IronMan and Difficulty settings from the shell
	Shell = UIShellDifficulty(`SCREENSTACK.GetFirstInstanceOf(class'UIShellDifficulty'));
	SelectedDifficulty = Shell.m_iSelectedDifficulty;
	IronmanFromShell = Shell.m_bIronmanFromShell;
	CampaignSettingsStateObject.SetDifficulty(SelectedDifficulty);
	CampaignSettingsStateObject.SetIronmanEnabled(IronmanFromShell);

	StartState.AddStateObject(CampaignSettingsStateObject);
	
	`XENGINE.SetAllowMovieInput(true);

	//`HQPRES.m_bExitFromSimCombat = true;
	
}
*/